calc_mode_date: Calculate mode of date vector

View source: R/calc_mode_date.R

calc_mode_dateR Documentation

Calculate mode of date vector

Description

Calculate mode of date vector

Usage

calc_mode_date(x)

Arguments

x

A character vector where each element is a date in "YYYY-MM-DD" format.

Value

Returns a date vector representing the modal date, or the mean of the modal dates if there is a tie.

Examples

calc_mode_date(c("2021-01-01", "2021-01-02", "2021-01-01"))

eventreport documentation built on March 11, 2026, 1:07 a.m.