View source: R/calc_mode_numeric.R
| calc_mode_numeric | R Documentation |
This function calculates the mode of a given numeric vector, and returns the smallest mode value if multiple modes exist.
calc_mode_numeric(x)
x |
A numeric vector. |
Returns a numeric vector representing the mode value. Returns the smallest mode value if multiple modes exist, and NA if the vector is empty or contains non-numeric elements.
calc_mode_numeric(c(1, 2, 2, 3, 4, 4))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.