| eventreport | R Documentation |
The 'eventreport' package provides tools for analyzing and aggregating event data on political violence. It includes functions for processing, visualizing, and summarizing event data.
- 'aggregate_maverick_con': Function for [describe what this does]. - 'mean_dscore': Function for [describe what this does].
Sebastian van Baalen & Kristine Hoglund (2024)
Sebastian van Baalen & Kristine Hoglund (2024) Trials and Triangulations: Aggregation Problems in Event Data on Political Violence. Uppsala: Uppsala University.
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.