Learn R Programming

eventreport (version 0.1.1)

maverick_event_report: The MAVERICK event report level dataset

Description

The Modes and Agents of Election-Related Violence in Côte d'Ivoire and Kenya (MAVERICK) is an event report level dataset of electoral violence incidents.

Usage

maverick_event_report

Arguments

Format

A data frame with 3287 rows and 108 columns.

id

A unique event report identifier.

event_id

A unique event identifier assigned by the coders. Needed to aggregate event reports into events.

country

A character class variable that contains the name of the country in which the event took place.

election

A character class variable that contains the name of the election to which the event was most closely associated.

certain

A numeric class variable that denotes the number of inclusion criteria that the event report fulfilled.

certain1

A integer class variable that denotes whether the reported event was inferred to be election-related because the event report or another event report explicitly identified the event as election-related.

certain2

A integer class variable that denotes whether the reported event was inferred to be election-related because at least one of the actors involved had explicit ties to a political party or was referred to by their party affiliation.

certain3

A integer class variable that denotes whether the reported event was inferred to be election-related because at least one of the targets was election-related, such as voters at a polling station, political candidates, election observers, security forces deployed to overlook the election, electoral material, or electoral infrastructure.

certain4

A integer class variable that denotes whether the reported event was inferred to be election-related because the reported purpose of the event was to influence an electoral process or outcome.

certain5

A integer class variable that denotes whether the reported event was inferred to be election-related because the event was part of an episode of electoral violence or occurred as a reaction to an earlier electoral violence event.

certain6

A integer class variable that denotes whether the the reported event was inferred to be election-related because it occurred at most 6 months prior to or after an election.

date_start

A character class variable that contains the earliest possible event date expressed in YYYY-MM-DD format.

date_end

A character class variable that contains the latest possible event date expressed in YYYY-MM-DD format.

city

A character class variable that contains the name of the city or village in which the event took place.

location

A character class variable that contains a text description of the most precise event location described in the report.

latitude

A numeric class variable that contains the latitude for the location indicated in location.

longitude

A numeric class variable that contains the longitude for the location indicated in location.

geo_precision

A numeric class variable that denotes how precisely the geo-coordinates are coded, ranging from the country level (1) to the exact street or building (6).

actor1

A character class variable that contains the name of the actor involved in the event.

actor1_id

A unique actor identifier assigned by the coders.

actor1_type

A character class variable that records the type of actor.

actor1_subtype

A character class variable that records the subtype of actor.

actor1_party

A character class variable that records the party affiliation of actor.

actor1_violence

A character class variable that records all forms of violence used by the actor.

actor1_precision

A numeric class variable that denotes how precisely the actor information is coded.

actor1_initiator

An integer class variable that denotes whether the actor was the initiator of the violence.

actor1_perpetrator

An integer class variable that denotes whether the actor was a perpetrator of the violence.

actor1_intervener

An integer class variable that denotes whether the actor was an intervener in the violence.

actor1_bystander

An integer class variable that denotes whether the actor was a passive bystander to the violence.

actor1_victim

An integer class variable that denotes whether the actor was also a victim of the violence.

actor2

A character class variable that contains the name of the actor involved in the event.

actor2_id

A unique actor identifier assigned by the coders.

actor2_type

A character class variable that records the type of actor.

actor2_subtype

A character class variable that records the subtype of actor.

actor2_party

A character class variable that records the party affiliation of actor.

actor2_violence

A character class variable that records all forms of violence used by the actor.

actor2_precision

A numeric class variable that denotes how precisely the actor information is coded.

actor2_initiator

An integer class variable that denotes whether the actor was the initiator of the violence.

actor2_perpetrator

An integer class variable that denotes whether the actor was a perpetrator of the violence.

actor2_intervener

An integer class variable that denotes whether the actor was an intervener in the violence.

actor2_bystander

An integer class variable that denotes whether the actor was a passive bystander to the violence.

actor2_victim

An integer class variable that denotes whether the actor was also a victim of the violence.

actor3

A character class variable that contains the name of the actor involved in the event.

actor3_id

A unique actor identifier assigned by the coders.

actor3_type

A character class variable that records the type of actor.

actor3_subtype

A character class variable that records the subtype of actor.

actor3_party

A character class variable that records the party affiliation of actor.

actor3_violence

A character class variable that records all forms of violence used by the actor.

actor3_precision

A numeric class variable that denotes how precisely the actor information is coded.

actor3_initiator

An integer class variable that denotes whether the actor was the initiator of the violence.

actor3_perpetrator

An integer class variable that denotes whether the actor was a perpetrator of the violence.

actor3_intervener

An integer class variable that denotes whether the actor was an intervener in the violence.

actor3_bystander

An integer class variable that denotes whether the actor was a passive bystander to the violence.

actor3_victim

An integer class variable that denotes whether the actor was also a victim of the violence.

actor4

A character class variable that contains the name of the actor involved in the event.

actor4_id

A unique actor identifier assigned by the coders.

actor4_type

A character class variable that records the type of actor.

actor4_subtype

A character class variable that records the subtype of actor.

actor4_party

A character class variable that records the party affiliation of actor.

actor4_violence

A character class variable that records all forms of violence used by the actor.

actor4_precision

A numeric class variable that denotes how precisely the actor information is coded.

actor4_initiator

An integer class variable that denotes whether the actor was the initiator of the violence.

actor4_perpetrator

An integer class variable that denotes whether the actor was a perpetrator of the violence.

actor4_intervener

An integer class variable that denotes whether the actor was an intervener in the violence.

actor4_bystander

An integer class variable that denotes whether the actor was a passive bystander to the violence.

actor4_victim

An integer class variable that denotes whether the actor was also a victim of the violence.

actor5

A character class variable that contains the name of the actor involved in the event.

actor5_id

A unique actor identifier assigned by the coders.

actor5_type

A character class variable that records the type of actor.

actor5_subtype

A character class variable that records the subtype of actor.

actor5_party

A character class variable that records the party affiliation of actor.

actor5_violence

A character class variable that records all forms of violence used by the actor.

actor5_precision

A numeric class variable that denotes how precisely the actor information is coded.

actor5_initiator

An integer class variable that denotes whether the actor was the initiator of the violence.

actor5_perpetrator

An integer class variable that denotes whether the actor was a perpetrator of the violence.

actor5_intervener

An integer class variable that denotes whether the actor was an intervener in the violence.

actor5_bystander

An integer class variable that denotes whether the actor was a passive bystander to the violence.

actor5_victim

An integer class variable that denotes whether the actor was also a victim of the violence.

actor6

A character class variable that contains the name of the actor involved in the event.

actor6_id

A unique actor identifier assigned by the coders.

actor6_type

A character class variable that records the type of actor.

actor6_subtype

A character class variable that records the subtype of actor.

actor6_party

A character class variable that records the party affiliation of actor.

actor6_violence

A character class variable that records all forms of violence used by the actor.

actor6_precision

A numeric class variable that denotes how precisely the actor information is coded.

actor6_initiator

An integer class variable that denotes whether the actor was the initiator of the violence.

actor6_perpetrator

An integer class variable that denotes whether the actor was a perpetrator of the violence.

actor6_intervener

An integer class variable that denotes whether the actor was an intervener in the violence.

actor6_bystander

An integer class variable that denotes whether the actor was a passive bystander to the violence.

actor6_victim

An integer class variable that denotes whether the actor was also a victim of the violence.

event_context

A character class variable that records the context in which the violence took place.

target

A character class variable that records the primary target of the violence

deaths_best

An integer class variable that records the best estimated number of deaths.

deaths_low

An integer class variable that records the lowest estimated number of deaths.

deaths_high

An integer class variable that records the highest estimated number of deaths.

injuries_best

An integer class variable that records the best estimated number of injured people.

injuries_low

An integer class variable that records the lowest estimated number of injured people.

injuries_high

An integer class variable that records the highest estimated number of injured people.

displacement

An integer class variable that denotes whether the event resulted in displacement.

damage

An integer class variable that denotes whether the event resulted in material destruction.

source

A character class variable that records the source.

number_of_sources

An integer class variable that records the number of sources the event is based on. Only relevant once the dataset is aggregated to the event level.

source_author

A character class variable that records the author of the source.

source_type

A character class variable that records the type of source.

source_classification

An integer class variable that denotes how reputable the source is considered.

sampling

An integer class variable that denotes whether the report was sampled from Factiva or another secondary source.

unit_of_analysis

A character class variable that records the unit of analysis.

aggregation

A character class variable that records the chosen aggregation model. Only relevant once the data is aggregated to the event level.