View source: R/calc_mode_date.R
| calc_mode_date | R Documentation |
Calculate mode of date vector
calc_mode_date(x)
x |
A character vector where each element is a date in "YYYY-MM-DD" format. |
Returns a date vector representing the modal date, or the mean of the modal dates if there is a tie.
calc_mode_date(c("2021-01-01", "2021-01-02", "2021-01-01"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.