Learn R Programming

eventreport (version 0.1.1)

calc_mode_date: Calculate mode of date vector

Description

Calculate mode of date vector

Usage

calc_mode_date(x)

Value

Returns a date vector representing the modal date, or the mean of the modal dates if there is a tie.

Arguments

x

A character vector where each element is a date in "YYYY-MM-DD" format.

Examples

Run this code
calc_mode_date(c("2021-01-01", "2021-01-02", "2021-01-01"))

Run the code above in your browser using DataLab