powered by
Calculate mode of date vector
calc_mode_date(x)
Returns a date vector representing the modal date, or the mean of the modal dates if there is a tie.
A character vector where each element is a date in "YYYY-MM-DD" format.
calc_mode_date(c("2021-01-01", "2021-01-02", "2021-01-01"))
Run the code above in your browser using DataLab