The Modes and Agents of Election-Related Violence in Côte d'Ivoire and Kenya (MAVERICK) is an event report level dataset of electoral violence incidents.
maverick_event_reportA data frame with 3287 rows and 108 columns.
A unique event report identifier.
A unique event identifier assigned by the coders. Needed to aggregate event reports into events.
A character class variable that contains the name of the country in which the event took place.
A character class variable that contains the name of the election to which the event was most closely associated.
A numeric class variable that denotes the number of inclusion criteria that the event report fulfilled.
A integer class variable that denotes whether the reported event was inferred to be election-related because the event report or another event report explicitly identified the event as election-related.
A integer class variable that denotes whether the reported event was inferred to be election-related because at least one of the actors involved had explicit ties to a political party or was referred to by their party affiliation.
A integer class variable that denotes whether the reported event was inferred to be election-related because at least one of the targets was election-related, such as voters at a polling station, political candidates, election observers, security forces deployed to overlook the election, electoral material, or electoral infrastructure.
A integer class variable that denotes whether the reported event was inferred to be election-related because the reported purpose of the event was to influence an electoral process or outcome.
A integer class variable that denotes whether the reported event was inferred to be election-related because the event was part of an episode of electoral violence or occurred as a reaction to an earlier electoral violence event.
A integer class variable that denotes whether the the reported event was inferred to be election-related because it occurred at most 6 months prior to or after an election.
A character class variable that contains the earliest possible event date expressed in YYYY-MM-DD format.
A character class variable that contains the latest possible event date expressed in YYYY-MM-DD format.
A character class variable that contains the name of the city or village in which the event took place.
A character class variable that contains a text description of the most precise event location described in the report.
A numeric class variable that contains the latitude for the location indicated in location.
A numeric class variable that contains the longitude for the location indicated in location.
A numeric class variable that denotes how precisely the geo-coordinates are coded, ranging from the country level (1) to the exact street or building (6).
A character class variable that contains the name of the actor involved in the event.
A unique actor identifier assigned by the coders.
A character class variable that records the type of actor.
A character class variable that records the subtype of actor.
A character class variable that records the party affiliation of actor.
A character class variable that records all forms of violence used by the actor.
A numeric class variable that denotes how precisely the actor information is coded.
An integer class variable that denotes whether the actor was the initiator of the violence.
An integer class variable that denotes whether the actor was a perpetrator of the violence.
An integer class variable that denotes whether the actor was an intervener in the violence.
An integer class variable that denotes whether the actor was a passive bystander to the violence.
An integer class variable that denotes whether the actor was also a victim of the violence.
A character class variable that contains the name of the actor involved in the event.
A unique actor identifier assigned by the coders.
A character class variable that records the type of actor.
A character class variable that records the subtype of actor.
A character class variable that records the party affiliation of actor.
A character class variable that records all forms of violence used by the actor.
A numeric class variable that denotes how precisely the actor information is coded.
An integer class variable that denotes whether the actor was the initiator of the violence.
An integer class variable that denotes whether the actor was a perpetrator of the violence.
An integer class variable that denotes whether the actor was an intervener in the violence.
An integer class variable that denotes whether the actor was a passive bystander to the violence.
An integer class variable that denotes whether the actor was also a victim of the violence.
A character class variable that contains the name of the actor involved in the event.
A unique actor identifier assigned by the coders.
A character class variable that records the type of actor.
A character class variable that records the subtype of actor.
A character class variable that records the party affiliation of actor.
A character class variable that records all forms of violence used by the actor.
A numeric class variable that denotes how precisely the actor information is coded.
An integer class variable that denotes whether the actor was the initiator of the violence.
An integer class variable that denotes whether the actor was a perpetrator of the violence.
An integer class variable that denotes whether the actor was an intervener in the violence.
An integer class variable that denotes whether the actor was a passive bystander to the violence.
An integer class variable that denotes whether the actor was also a victim of the violence.
A character class variable that contains the name of the actor involved in the event.
A unique actor identifier assigned by the coders.
A character class variable that records the type of actor.
A character class variable that records the subtype of actor.
A character class variable that records the party affiliation of actor.
A character class variable that records all forms of violence used by the actor.
A numeric class variable that denotes how precisely the actor information is coded.
An integer class variable that denotes whether the actor was the initiator of the violence.
An integer class variable that denotes whether the actor was a perpetrator of the violence.
An integer class variable that denotes whether the actor was an intervener in the violence.
An integer class variable that denotes whether the actor was a passive bystander to the violence.
An integer class variable that denotes whether the actor was also a victim of the violence.
A character class variable that contains the name of the actor involved in the event.
A unique actor identifier assigned by the coders.
A character class variable that records the type of actor.
A character class variable that records the subtype of actor.
A character class variable that records the party affiliation of actor.
A character class variable that records all forms of violence used by the actor.
A numeric class variable that denotes how precisely the actor information is coded.
An integer class variable that denotes whether the actor was the initiator of the violence.
An integer class variable that denotes whether the actor was a perpetrator of the violence.
An integer class variable that denotes whether the actor was an intervener in the violence.
An integer class variable that denotes whether the actor was a passive bystander to the violence.
An integer class variable that denotes whether the actor was also a victim of the violence.
A character class variable that contains the name of the actor involved in the event.
A unique actor identifier assigned by the coders.
A character class variable that records the type of actor.
A character class variable that records the subtype of actor.
A character class variable that records the party affiliation of actor.
A character class variable that records all forms of violence used by the actor.
A numeric class variable that denotes how precisely the actor information is coded.
An integer class variable that denotes whether the actor was the initiator of the violence.
An integer class variable that denotes whether the actor was a perpetrator of the violence.
An integer class variable that denotes whether the actor was an intervener in the violence.
An integer class variable that denotes whether the actor was a passive bystander to the violence.
An integer class variable that denotes whether the actor was also a victim of the violence.
A character class variable that records the context in which the violence took place.
A character class variable that records the primary target of the violence
An integer class variable that records the best estimated number of deaths.
An integer class variable that records the lowest estimated number of deaths.
An integer class variable that records the highest estimated number of deaths.
An integer class variable that records the best estimated number of injured people.
An integer class variable that records the lowest estimated number of injured people.
An integer class variable that records the highest estimated number of injured people.
An integer class variable that denotes whether the event resulted in displacement.
An integer class variable that denotes whether the event resulted in material destruction.
A character class variable that records the source.
An integer class variable that records the number of sources the event is based on. Only relevant once the dataset is aggregated to the event level.
A character class variable that records the author of the source.
A character class variable that records the type of source.
An integer class variable that denotes how reputable the source is considered.
An integer class variable that denotes whether the report was sampled from Factiva or another secondary source.
A character class variable that records the unit of analysis.
A character class variable that records the chosen aggregation model. Only relevant once the data is aggregated to the event level.