Learn R Programming

eventreport (version 0.1.1)

small_maverick_event_report: A Subset of the MAVERICK Event Report Dataset

Description

This dataset contains 100 event reports from the MAVERICK event report dataset, arranged by `event_id`. It is used for examples and vignettes in the `eventreport` package.

Usage

small_maverick_event_report

Arguments

Format

A subset of the MAVERICK data frame with 100 rows and 10 columns:

id

A unique event report identifier.

event_id

A unique event identifier assigned by the coders. Needed to aggregate event reports into events.

country

A character class variable that contains the name of the country in which the event took place.

date_start

A character class variable that contains the earliest possible event date expressed in YYYY-MM-DD format.

city

A character class variable that contains the name of the city or village in which the event took place.

location

A character class variable that contains a text description of the most precise event location described in the report.

actor1

A character class variable that contains the name of the actor involved in the event.

deaths_best

An integer class variable that records the best estimated number of deaths.

injuries_best

An integer class variable that records the best estimated number of injured people.

source

A character class variable that records the source.

...