This dataset contains 100 event reports from the MAVERICK event report dataset, arranged by `event_id`. It is used for examples and vignettes in the `eventreport` package.
small_maverick_event_reportA subset of the MAVERICK data frame with 100 rows and 10 columns:
A unique event report identifier.
A unique event identifier assigned by the coders. Needed to aggregate event reports into events.
A character class variable that contains the name of the country in which the event took place.
A character class variable that contains the earliest possible event date expressed in YYYY-MM-DD format.
A character class variable that contains the name of the city or village in which the event took place.
A character class variable that contains a text description of the most precise event location described in the report.
A character class variable that contains the name of the actor involved in the event.
An integer class variable that records the best estimated number of deaths.
An integer class variable that records the best estimated number of injured people.
A character class variable that records the source.
...